@@ -15,7 +15,7 @@ class AvroEncoder:
         if not schemaless:
             raise Exception("AvroEncoder does not support encoding schema into records")
 
-        parsed_schema = avroschema.Parse(json.dumps(schema))
+        parsed_schema = avroschema.parse(json.dumps(schema))
         self._encoder = avro.io.DatumWriter(parsed_schema)
 
     def encode(self, schema_id, record):
