@@ -16,3 +16,9 @@ class SchemaMeta:
                     type(schema)
                 )
             )
+
+
+class Schema:
+    def __init__(self, schema, id):
+        self.id = id
+        self.schema = json.loads(schema)
